# Marauder's Map

Define your Rails routes along side all your other Domain Driven stuff.


[![Build Status](https://badge.buildkite.com/dc56f7573ed90bb9401e617839fcdbb65d71559de2de41da0a.svg)](https://buildkite.com/wellware/marauders-map)

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'marauders_map'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install marauders_map

## Usage

#### Update `config/routes.rb` to include this:

``` ruby
MaraudersMap.reveal_routes!
``` 

Put this _after_ any routes that haven't been relocated. Preferably at the end of the file.

#### Define your routes in the same place you manage your domains. For example, in `app/domains/sorting_hat/routes.rb`:

``` ruby
MaraudersMap.draw(:sorting_hat) do
  resource :house do
    get :gryffindor, on: :member
    get :hufflepuff, on: :member
    get :slytherin, on: :member
    get :ravenclaw, on: :meber
  end
end
```

The routing DSL is exactly the same as the one you use in your traditional routes files. The only difference is you wrap them in a `MaraudersMap.draw(:domain)` block.


## TODO:

- [ ] Investigate potential issue when routes are autoloaded (as opposed to eager loaded)

- [ ] Easily examine generated routes (filter by domain)


## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake test` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome  at https://code.wellware.dev/leemachin/marauders_map.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
